# weppy-Assets

weppy-Assets is an extension for [weppy framework](http://weppy.org) providing a complete assets management system. It's based on [webassets](https://github.com/miracle2k/webassets) package and integrates all its filters.

## Installation

You can install weppy-Assets using pip:

    pip install weppy-Assets

And add it to your weppy application:

```python
from weppy_assets import Assets

app.use_extension(Assets)
```

## Documentation

The complete documentation is available on the [weppy extensions registry](http://weppy.org/extensions/assets).

## License

weppy-Assets is released under BSD license. Check the LICENSE file for more details.
